# -*- coding:utf-8 -*-
def print_lol(the_list, level = 0):
#读取两个参数，"the_list"读取列表，"level"读取一个为0的数来进行嵌套。
    for a in the_list:
        if isinstance(a, list):
#判断列表中，是否还存在另一个列表，如果存在，就进行递归，"level"的值+1。。
            print_lol(a, level + 1)
        else:
#"level"的值是从0开始，如果在最开始没有遇到列表，是不会打印制表符的。但是如果遇到一个列表就会因为"level"的值+1，而打印一个制表符。
            for b in range(level):
                print("\t", end = "")
            print(a)
